aboutsummaryrefslogtreecommitdiff
path: root/lib/transfer.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/transfer.c')
-rw-r--r--lib/transfer.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/transfer.c b/lib/transfer.c
index 5758dad47..97a085d54 100644
--- a/lib/transfer.c
+++ b/lib/transfer.c
@@ -2136,7 +2136,7 @@ CURLcode Curl_perform(struct SessionHandle *data)
if(res == CURLE_OK) {
if (data->set.source_url) /* 3rd party transfer */
- res = Curl_pretransfersec(conn);
+ res = Curl_second_connect(conn);
else
conn->sec_conn = NULL;
}
@@ -2250,10 +2250,10 @@ Curl_Transfer(struct connectdata *c_conn, /* connection data */
}
/*
* Curl_pretransfersec() prepares the secondary connection (used for 3rd party
* FTP transfers).
*/
-CURLcode Curl_pretransfersec(struct connectdata *conn)
+CURLcode Curl_second_connect(struct connectdata *conn)
{
CURLcode status = CURLE_OK;
struct SessionHandle *data = conn->data;
@@ -2250,10 +2250,10 @@ Curl_Transfer(struct connectdata *c_conn, /* connection data */
}
/*
- * Curl_pretransfersec() prepares the secondary connection (used for 3rd party
+ * Curl_second_connect() makes the secondary connection (used for 3rd party
* FTP transfers).
*/